.. _changelog:

=========
CHANGELOG
=========


.. _changelog-v0.0.6:

v0.0.6 (2025-02-12)
===================

Bug Fixes
---------

* fix: version bump (`908871d`_)

Unknown
-------

* update deployment for new pypi rules (`b533a29`_)

* update url (`27ad05a`_)

* Merge branch 'main' of github.com:nrsur-catalog/nrsur_catalog (`b4a6767`_)

.. _908871d: https://github.com/nrsur-catalog/nrsur_catalog/commit/908871dfe469690999441ac5867f03f5063b2876
.. _b533a29: https://github.com/nrsur-catalog/nrsur_catalog/commit/b533a2982448e01bc084009734c3c446462ec318
.. _27ad05a: https://github.com/nrsur-catalog/nrsur_catalog/commit/27ad05a6967ac827b46d784d2d71aa7c8d932315
.. _b4a6767: https://github.com/nrsur-catalog/nrsur_catalog/commit/b4a67676c57d4e3d4e62a40b4212caa51f19df8b


.. _changelog-v0.0.5:

v0.0.5 (2023-09-24)
===================

Unknown
-------

* Update __init__.py

update version (`de3e2d7`_)

* Update __init__.py

update website (`d2a06a5`_)

* Update README.md

More info in the README (`8cd550e`_)

* Update README.md

fix badge link (`4db4558`_)

* add paper link (`f823410`_)

.. _de3e2d7: https://github.com/nrsur-catalog/nrsur_catalog/commit/de3e2d7fd0f45ad2c8cc1bc35e35dbedb42fdf20
.. _d2a06a5: https://github.com/nrsur-catalog/nrsur_catalog/commit/d2a06a59bced41447687df9626794dd7dc4ffeb9
.. _8cd550e: https://github.com/nrsur-catalog/nrsur_catalog/commit/8cd550ee11b89fe47b06f28aa02f1816631e535b
.. _4db4558: https://github.com/nrsur-catalog/nrsur_catalog/commit/4db4558594dc2d7835deff6080aa77366c40e415
.. _f823410: https://github.com/nrsur-catalog/nrsur_catalog/commit/f8234103eb059ac585d7daaf0365d5aa0f1a6c94


.. _changelog-v0.0.4:

v0.0.4 (2023-09-20)
===================

Unknown
-------

* v0.0.4 (`45ccd65`_)

* remove some redundant functions (`69deb93`_)

* plotting fixes (`f84f572`_)

* Merge branch 'main' of github.com:nrsur-catalog/nrsur_catalog (`04af39f`_)

* Merge pull request #2 from nrsur-catalog/v0.0.3

v0.0.3 (`69ebc8b`_)

* v0.0.3 (`a6ad271`_)

* use vijay comments (`77ff67c`_)

.. _45ccd65: https://github.com/nrsur-catalog/nrsur_catalog/commit/45ccd65b5a034034a345259c12b9547fb5bbc8e8
.. _69deb93: https://github.com/nrsur-catalog/nrsur_catalog/commit/69deb93515a93bb90c480428e5fa341a75d34e6f
.. _f84f572: https://github.com/nrsur-catalog/nrsur_catalog/commit/f84f572a36410985cf8ca6838c5622b4eb34b3a6
.. _04af39f: https://github.com/nrsur-catalog/nrsur_catalog/commit/04af39ff864ab32ec30cddc49fc256809c0ac5e6
.. _69ebc8b: https://github.com/nrsur-catalog/nrsur_catalog/commit/69ebc8b69df19a4ecac547f80fab9c24043164c7
.. _a6ad271: https://github.com/nrsur-catalog/nrsur_catalog/commit/a6ad2718f6762454bf5aa4eb24726054190c10dd
.. _77ff67c: https://github.com/nrsur-catalog/nrsur_catalog/commit/77ff67c5addd565919fadd9f676e978bf06143a4


.. _changelog-v0.0.3:

v0.0.3 (2023-09-14)
===================

Unknown
-------

* restructure pcakge to not need datafiles (`4aa0376`_)

* remove website stuff (`969bbe2`_)

* Merge branch 'main' of github.com:sxs-collaboration/nrsur_catalog (`5014e72`_)

* Merge pull request #3 from sxs-collaboration/fix_setup_data

fix setup datapaths (`ef12e62`_)

* fix setup datapaths (`d0287ce`_)

* Update README.md (`121284c`_)

* refactor menu page to not use itables (`3ba23dc`_)

* refactor (`9834fe1`_)

* add cli tests for downloading (`c69c801`_)

* updated vid urls (`8a4d557`_)

* video uploader added (`969755b`_)

* Create generate_video_info_json.py (`c096790`_)

* Create youtube_uploader.py (`19bdc15`_)

* add pypi version (`8c81c02`_)

* update vers (`a29b4a6`_)

* split README into README and DDEPLOYMENT (`664f285`_)

* allow manual pypi build (`1a2ae24`_)

* add metadata for pypi release (`fcc7ef9`_)

* add metadata for pypi release (`2badf09`_)

* update weburl (`f104f12`_)

.. _4aa0376: https://github.com/nrsur-catalog/nrsur_catalog/commit/4aa037616e35c6b98b6707cf39785de34acbdf2b
.. _969bbe2: https://github.com/nrsur-catalog/nrsur_catalog/commit/969bbe21276cfadedf9a849e8588ebbb1c76336e
.. _5014e72: https://github.com/nrsur-catalog/nrsur_catalog/commit/5014e72d5067985f87f3470b3c3463f4dc840321
.. _ef12e62: https://github.com/nrsur-catalog/nrsur_catalog/commit/ef12e624e7b47d0a2ed2daeac70a602cef0c2df3
.. _d0287ce: https://github.com/nrsur-catalog/nrsur_catalog/commit/d0287ce51131f5c74b1995643ce6cb6d994559bf
.. _121284c: https://github.com/nrsur-catalog/nrsur_catalog/commit/121284ccbf7181064c90a33b93b2071d05e85cd3
.. _3ba23dc: https://github.com/nrsur-catalog/nrsur_catalog/commit/3ba23dc9cf2c61e69f67ef4f048bf2b222b3f9c4
.. _9834fe1: https://github.com/nrsur-catalog/nrsur_catalog/commit/9834fe1c2271d2256f0bcb494de484073a243def
.. _c69c801: https://github.com/nrsur-catalog/nrsur_catalog/commit/c69c8016ff770c3cfaeb230601ddda0103d1e123
.. _8a4d557: https://github.com/nrsur-catalog/nrsur_catalog/commit/8a4d5577a0283e554d232ffd40d2b880a2ccdfb2
.. _969755b: https://github.com/nrsur-catalog/nrsur_catalog/commit/969755b9db0c49448017575d6a074225e5f915ea
.. _c096790: https://github.com/nrsur-catalog/nrsur_catalog/commit/c096790a4a9d0e172eaa4bcd891077e6b0b07f1e
.. _19bdc15: https://github.com/nrsur-catalog/nrsur_catalog/commit/19bdc158432ee710247ba8780572cf2a797950fd
.. _8c81c02: https://github.com/nrsur-catalog/nrsur_catalog/commit/8c81c029024b59cd4019aedf1dce1aea94f431e2
.. _a29b4a6: https://github.com/nrsur-catalog/nrsur_catalog/commit/a29b4a6816cad69208e18f8212ff515918832191
.. _664f285: https://github.com/nrsur-catalog/nrsur_catalog/commit/664f285130036a95950a146d6e614c903b56beb2
.. _1a2ae24: https://github.com/nrsur-catalog/nrsur_catalog/commit/1a2ae24c07de85c189db7b15d542056cc44005ed
.. _fcc7ef9: https://github.com/nrsur-catalog/nrsur_catalog/commit/fcc7ef940804bab8b1aa68b4505850448f31d6d2
.. _2badf09: https://github.com/nrsur-catalog/nrsur_catalog/commit/2badf092677ac0afbc7884b5cc45ed4c94278d98
.. _f104f12: https://github.com/nrsur-catalog/nrsur_catalog/commit/f104f124dd610b8f72e19190427707c701e70493


.. _changelog-v0.0.1:

v0.0.1 (2023-08-02)
===================

Unknown
-------

* add url (`2fb021c`_)

* add release workflow and youtube links (`efafca4`_)

* Update README.md (`c9162ad`_)

* add cjhaster/NRsurrogate_catalog (`5b6f6c5`_)

* add some gwcloud helper scripts (`718f3a7`_)

* refactor (`7dcf44d`_)

* update website (`7bdbb4f`_)

* start adding GWCloud stuff (`11d2478`_)

* hide extra logs (`77f52cc`_)

* updates to layouts (`fc22b90`_)

* update urls [automated] (`3c36ee3`_)

* remove log prior (`0aeddbd`_)

* update to use Tousifs new version (`f358ff3`_)

* update urls [automated] (`bbf3eb3`_)

* update urls [automated] (`fbbe998`_)

* update pages (`01bb958`_)

* convert results (`e38d321`_)

* add lvk data urls (`9708c5b`_)

* improve web layout (`132d67c`_)

* tabs for plot images (`e84a208`_)

* update urls [automated] (`7b06053`_)

* add plotly plotter (`ac22702`_)

* add plots (`2264cae`_)

* update urls [automated] (`2c7ecf0`_)

* save as py (`9177792`_)

* update urls [automated] (`e23d00e`_)

* save as md (`ce8d9ed`_)

* update urls [automated] (`c3e4f23`_)

* add temp violin plot (`6cf59c2`_)

* update interface (`0537df8`_)

* update urls [automated] (`28934dd`_)

* update urls [automated] (`71518d4`_)

* add boilerplate config + analysis download options (`aad5e1c`_)

* add boilerplate config + analysis download options (`4f3ee92`_)

* remove binder link (`c324b91`_)

* update weblink (`1e669b5`_)

* fix paths (`6769b01`_)

* adjustements to zenodo download interface (`60904fb`_)

* update urls [automated] (`fd8944c`_)

* update urls [automated] (`7ec1d65`_)

* update urls [automated] (`ee620dc`_)

* update urls [automated] (`5926924`_)

* update web interface (`7f4b366`_)

* update urls [automated] (`f774a5c`_)

* update urls [automated] (`aed8743`_)

* Update /Users/avaj0001/Documents/projects/nrsurrogate_catalog/src/nrsur_catalog/api/zenodo_urls.txt (`f2f86bf`_)

* Merge pull request #4 from cjhaster/website

minor changes (`231a0c0`_)

* Merge remote-tracking branch 'origin/main' into website (`7e7d1a4`_)

* Merge pull request #3 from cjhaster/website

update website code (`945f597`_)

* minor fixes (`ffc4d76`_)

* updates to web interface (`82c5ffc`_)

* refactoring (`f61e3ce`_)

* init website (`65995ec`_)

* Update README.md (`eb6519d`_)

* Initial commit (`13bee7e`_)

.. _2fb021c: https://github.com/nrsur-catalog/nrsur_catalog/commit/2fb021c1acd4f4f59907fe385c933804442a4c14
.. _efafca4: https://github.com/nrsur-catalog/nrsur_catalog/commit/efafca45db9ea6f4533ef7d27826619a3b4c2da4
.. _c9162ad: https://github.com/nrsur-catalog/nrsur_catalog/commit/c9162adc88a3f25c5cc5365de029426bc45e6dda
.. _5b6f6c5: https://github.com/nrsur-catalog/nrsur_catalog/commit/5b6f6c5b43a3ae40351929eea79329864fbcddf8
.. _718f3a7: https://github.com/nrsur-catalog/nrsur_catalog/commit/718f3a7f8e62df34aa4763c6ecf626fc420bbc40
.. _7dcf44d: https://github.com/nrsur-catalog/nrsur_catalog/commit/7dcf44d0093bf3a99d17dcae2b5060acb8dce0dc
.. _7bdbb4f: https://github.com/nrsur-catalog/nrsur_catalog/commit/7bdbb4f882c6cd907b4c29f87110a5ce419acf6c
.. _11d2478: https://github.com/nrsur-catalog/nrsur_catalog/commit/11d24785f57d5366ebbbb0e7d0e5839bcc30671d
.. _77f52cc: https://github.com/nrsur-catalog/nrsur_catalog/commit/77f52cc67171ea79baf6e705243124d281f45c41
.. _fc22b90: https://github.com/nrsur-catalog/nrsur_catalog/commit/fc22b905a748be266aff432679144c28f760af68
.. _3c36ee3: https://github.com/nrsur-catalog/nrsur_catalog/commit/3c36ee37d420f9d3344021c73523092b975553d4
.. _0aeddbd: https://github.com/nrsur-catalog/nrsur_catalog/commit/0aeddbd55a53241e0451a4d63b968bb961a80732
.. _f358ff3: https://github.com/nrsur-catalog/nrsur_catalog/commit/f358ff36a01fb10dd58fab88ab9ee26f433a982f
.. _bbf3eb3: https://github.com/nrsur-catalog/nrsur_catalog/commit/bbf3eb39d56bcbc7ae24d9ff3b2d3f502d7677f9
.. _fbbe998: https://github.com/nrsur-catalog/nrsur_catalog/commit/fbbe9988996c1cd6cf2b810b01e0886159a9f423
.. _01bb958: https://github.com/nrsur-catalog/nrsur_catalog/commit/01bb95847d41c69ce7ef38cedecaf45df33c2530
.. _e38d321: https://github.com/nrsur-catalog/nrsur_catalog/commit/e38d321bb417a6fcefcec2a4b72aff3675d6dfb9
.. _9708c5b: https://github.com/nrsur-catalog/nrsur_catalog/commit/9708c5ba05a9f710c2427a6705658adfb74cdf66
.. _132d67c: https://github.com/nrsur-catalog/nrsur_catalog/commit/132d67cf21e3733cafcc9326313573c61ff2d23a
.. _e84a208: https://github.com/nrsur-catalog/nrsur_catalog/commit/e84a208f6de7680be259ae5b9a1a0110c08dee6a
.. _7b06053: https://github.com/nrsur-catalog/nrsur_catalog/commit/7b0605341cdb0481537fa0c4df89ddf8243cb320
.. _ac22702: https://github.com/nrsur-catalog/nrsur_catalog/commit/ac2270296bfd40e9a80d65b9c2e4edbc423d2f9a
.. _2264cae: https://github.com/nrsur-catalog/nrsur_catalog/commit/2264caea88bf84dd30702da0ef9a987c9db6fb81
.. _2c7ecf0: https://github.com/nrsur-catalog/nrsur_catalog/commit/2c7ecf0493d5f94050799e3a34fa129f770eabd6
.. _9177792: https://github.com/nrsur-catalog/nrsur_catalog/commit/91777929b00f4e9f5fac0ea322c2fe19786333c5
.. _e23d00e: https://github.com/nrsur-catalog/nrsur_catalog/commit/e23d00e3bb4ed80172e205a5a058cbd9547a4152
.. _ce8d9ed: https://github.com/nrsur-catalog/nrsur_catalog/commit/ce8d9edd2159e8dab67f0cd89e5d8e9877223cfe
.. _c3e4f23: https://github.com/nrsur-catalog/nrsur_catalog/commit/c3e4f2328590d4fc784c7c00ca6380d6ced3fcf1
.. _6cf59c2: https://github.com/nrsur-catalog/nrsur_catalog/commit/6cf59c2ded0af054f7e2fec66f484080831e6dbd
.. _0537df8: https://github.com/nrsur-catalog/nrsur_catalog/commit/0537df86004c4d1919fb425bb427c062e1f20bc2
.. _28934dd: https://github.com/nrsur-catalog/nrsur_catalog/commit/28934dd304ff3bdaf986d81546750b82160eca7a
.. _71518d4: https://github.com/nrsur-catalog/nrsur_catalog/commit/71518d4097907fca4c196c03220b92d7dc972298
.. _aad5e1c: https://github.com/nrsur-catalog/nrsur_catalog/commit/aad5e1cd4fb035e7b89b1ea9de25d3ff3bae7088
.. _4f3ee92: https://github.com/nrsur-catalog/nrsur_catalog/commit/4f3ee9252e01285ce8d91f53f4280f6ce8922771
.. _c324b91: https://github.com/nrsur-catalog/nrsur_catalog/commit/c324b91d9102e01f33d856b5eab1a24ee889dcc8
.. _1e669b5: https://github.com/nrsur-catalog/nrsur_catalog/commit/1e669b5e0b04f90faca96a7f0e64f649e8d05231
.. _6769b01: https://github.com/nrsur-catalog/nrsur_catalog/commit/6769b015972f8e627f35e53d09dc554c705bc759
.. _60904fb: https://github.com/nrsur-catalog/nrsur_catalog/commit/60904fb5a0ffe3b29d6977c5010ec2a0627e88fa
.. _fd8944c: https://github.com/nrsur-catalog/nrsur_catalog/commit/fd8944cf4491aa4df3d6c00a050c37e5a5a913ff
.. _7ec1d65: https://github.com/nrsur-catalog/nrsur_catalog/commit/7ec1d65bd21f2a03098b1786ca183db681369097
.. _ee620dc: https://github.com/nrsur-catalog/nrsur_catalog/commit/ee620dcc2085980d1cd705bb29f4e1e542503a0a
.. _5926924: https://github.com/nrsur-catalog/nrsur_catalog/commit/5926924592498e194254ffe280aa12b73cfe1b0e
.. _7f4b366: https://github.com/nrsur-catalog/nrsur_catalog/commit/7f4b366a0da60ee9b95df449c3708811d36e3bb1
.. _f774a5c: https://github.com/nrsur-catalog/nrsur_catalog/commit/f774a5c80d1d531b0c027ddf4f214f27ab0c87c1
.. _aed8743: https://github.com/nrsur-catalog/nrsur_catalog/commit/aed87436d3eb184f0c4c145298f8445fedd7297d
.. _f2f86bf: https://github.com/nrsur-catalog/nrsur_catalog/commit/f2f86bfd89a04a5d6b538955a85d4989fafe09d8
.. _231a0c0: https://github.com/nrsur-catalog/nrsur_catalog/commit/231a0c0f2c996361bc3537d8a5c94d10850dfaa0
.. _7e7d1a4: https://github.com/nrsur-catalog/nrsur_catalog/commit/7e7d1a4bf737da8a03a6a07290851edaf3e51eb7
.. _945f597: https://github.com/nrsur-catalog/nrsur_catalog/commit/945f597acbb89aee32230ab3832415db29597349
.. _ffc4d76: https://github.com/nrsur-catalog/nrsur_catalog/commit/ffc4d765492ba5112feba7e21e7b4cbd5f1786ab
.. _82c5ffc: https://github.com/nrsur-catalog/nrsur_catalog/commit/82c5ffcee2714335cc78ed6adfcfe2c1ff0fda8f
.. _f61e3ce: https://github.com/nrsur-catalog/nrsur_catalog/commit/f61e3cecc3d7e441d04d1887e7ef5a4419c3008e
.. _65995ec: https://github.com/nrsur-catalog/nrsur_catalog/commit/65995ecefe5b002fb8a6a19207bd80c4c3ded02d
.. _eb6519d: https://github.com/nrsur-catalog/nrsur_catalog/commit/eb6519dab1e85ea4489f98e7f4d95d53587587e1
.. _13bee7e: https://github.com/nrsur-catalog/nrsur_catalog/commit/13bee7e77d711fda73d79dcff5cb9039e19fd0ac
